<?php

namespace Drupal\seo_alt_hreflang\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Config\TypedConfigManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Language\LanguageManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure alternative hreflang settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * The language manager service.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * Constructs an object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   * @param \Drupal\Core\Config\TypedConfigManagerInterface $typed_config_manager
   *   The typed config manager.
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   *   The language manager service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, TypedConfigManagerInterface $typed_config_manager, LanguageManagerInterface $language_manager) {
    parent::__construct($config_factory, $typed_config_manager);
    $this->languageManager = $language_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
      $container->get('language_manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'seo_alt_hreflang_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $languages = $this->languageManager->getLanguages();
    $form['seo_alt_hreflang'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Alternative Hreflang Language Codes'),
      '#tree' => TRUE,
    ];
    $hreflangValues = $this->config('seo_alt_hreflang.settings')
      ->get('seo_alt_hreflang_list');
    foreach ($languages as $langcode => $language) {
      $form['seo_alt_hreflang'][$langcode] = [
        '#type' => 'textfield',
        '#title' => $language->getName() . ' (' . $langcode . ')',
        '#default_value' => $hreflangValues[$langcode] ?? NULL,
      ];
    }
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $conf = $this->config('seo_alt_hreflang.settings');
    $values = $form_state->getValue('seo_alt_hreflang');
    $values = array_filter(array_map('trim', array_filter($values)));
    $conf->set('seo_alt_hreflang_list', $values);
    $conf->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['seo_alt_hreflang.settings'];
  }

}
